@@ -1,10 +1,11 @@
-from typing import Any, Dict, List, Optional, Tuple, Union, TypedDict
+from typing import Any, Dict, List, Optional, Tuple, TypedDict, Union
 
 
 class IndicatorRow(TypedDict):
     """
     Type hinting for the input to 'indicator_table' objects
     """
+
     value: Optional[Union[str, int, float]]
     name: Optional[str]
     group: Optional[str]
